Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(297)

Unified Diff: net/quic/quic_http_stream.cc

Issue 2073323003: QUIC - Added a histogram to track number of times session_ is null when (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Fix comments Created 4 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | tools/metrics/histograms/histograms.xml » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/quic/quic_http_stream.cc
diff --git a/net/quic/quic_http_stream.cc b/net/quic/quic_http_stream.cc
index 7598a1ff97f8141d7ec1f03d41f8bb4cc0a6863c..d3fd026570810ccb184bacaf05b0e6455a234b9d 100644
--- a/net/quic/quic_http_stream.cc
+++ b/net/quic/quic_http_stream.cc
@@ -611,9 +611,13 @@ int QuicHttpStream::DoLoop(int rv) {
}
int QuicHttpStream::DoStreamRequest() {
- if (session_.get() == nullptr) {
- // TODO(rtenneti) Bug: b/28676259 - a temporary fix until we find out why
- // |session_| could be a nullptr.
+ // TODO(rtenneti) Bug: b/28676259 - a temporary fix until we find out why
+ // |session_| could be a nullptr. Delete |null_session| check and histogram if
+ // session is never a nullptr.
+ bool null_session = session_ == nullptr;
+ if (null_session) {
+ UMA_HISTOGRAM_BOOLEAN("Net.QuicHttpStream::DoStreamRequest.IsNullSession",
+ null_session);
return was_handshake_confirmed_ ? ERR_CONNECTION_CLOSED
: ERR_QUIC_HANDSHAKE_FAILED;
}
« no previous file with comments | « no previous file | tools/metrics/histograms/histograms.xml » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698